@@ -504,7 +504,7 @@ class BackupEngine {
         try {
             // Create backup history record with pending status
             $history = new BackupHistory($this->db);
-            $backupId = $history->create([
+            $result = $history->create([
                 'target_id' => $targetId,
                 'user' => $site['user'],
                 'backup_type' => 'wordpress',
@@ -520,13 +520,16 @@ class BackupEngine {
                 ]
             ]);
 
-            if (!$backupId) {
+            if (!$result) {
                 return [
                     'success' => false,
                     'error' => "Failed to create backup record"
                 ];
             }
 
+            // Get the actual backup ID
+            $backupId = $history->getId();
+
             // Trigger background processing
             $this->triggerBackgroundProcessing();
 
