@@ -29,8 +29,8 @@ class BackupJob {
         $history = new BackupHistory($this->db, $backupId);
         $data = $history->getData();
         
-        if ($data['status'] !== 'pending') {
-            throw new Exception("Backup is not in pending status, current status: " . $data['status']);
+        if ($data['status'] !== 'pending' && $data['status'] !== 'claimed') {
+            throw new Exception("Backup is not in pending or claimed status, current status: " . $data['status']);
         }
         
         // Update status to running
