@@ -38,8 +38,8 @@ function process_pending_backups() {
 
         log_message("Using maximum concurrent backups: $max_concurrent");
 
-        // Count currently running backups
-        $stmt = $db->prepare("SELECT COUNT(*) FROM backup_history WHERE status = 'processing'");
+        // Count currently running backups (BackupJob uses 'running' status, not 'processing')
+        $stmt = $db->prepare("SELECT COUNT(*) FROM backup_history WHERE status = 'running'");
         $stmt->execute();
         $running_count = $stmt->fetchColumn();
 
@@ -55,10 +55,26 @@ function process_pending_backups() {
 
         log_message("Available backup slots: $available_slots");
 
-        // Get pending backups (limit to available slots)
-        $stmt = $db->prepare("SELECT id FROM backup_history WHERE status = 'pending' ORDER BY started_at ASC LIMIT ?");
-        $stmt->execute([$available_slots]);
-        $backups = $stmt->fetchAll(PDO::FETCH_ASSOC);
+        // Get pending backups (limit to available slots) with atomic update to prevent race conditions
+        $db->beginTransaction();
+        try {
+            $stmt = $db->prepare("SELECT id FROM backup_history WHERE status = 'pending' ORDER BY started_at ASC LIMIT ? FOR UPDATE");
+            $stmt->execute([$available_slots]);
+            $backups = $stmt->fetchAll(PDO::FETCH_ASSOC);
+
+            // Immediately mark selected backups as 'running' to prevent other workers from taking them
+            if (!empty($backups)) {
+                $backupIds = array_column($backups, 'id');
+                $placeholders = str_repeat('?,', count($backupIds) - 1) . '?';
+                $stmt = $db->prepare("UPDATE backup_history SET status = 'running' WHERE id IN ($placeholders)");
+                $stmt->execute($backupIds);
+            }
+
+            $db->commit();
+        } catch (Exception $e) {
+            $db->rollback();
+            throw $e;
+        }
         
         if (empty($backups)) {
             log_message("No pending backups found");
@@ -87,12 +103,37 @@ function process_pending_backups() {
 
 // Main execution
 if (php_sapi_name() === 'cli') {
-    log_message("Backup worker started");
-    
-    // Process pending backups
-    process_pending_backups();
-    
+    $lockFile = '/tmp/backup-worker.lock';
+
+    // Create lock file with current PID
+    $pid = getmypid();
+    if (file_put_contents($lockFile, $pid) === false) {
+        log_message("Failed to create lock file, exiting");
+        exit(1);
+    }
+
+    // Register shutdown function to clean up lock file
+    register_shutdown_function(function() use ($lockFile) {
+        if (file_exists($lockFile)) {
+            unlink($lockFile);
+        }
+    });
+
+    log_message("Backup worker started (PID: $pid)");
+
+    try {
+        // Process pending backups
+        process_pending_backups();
+    } catch (Exception $e) {
+        log_message("Fatal error in backup worker: " . $e->getMessage());
+    }
+
     log_message("Backup worker finished");
+
+    // Clean up lock file
+    if (file_exists($lockFile)) {
+        unlink($lockFile);
+    }
 } else {
     echo "This script can only be run from command line\n";
     exit(1);
